#
# spec file for package fcitx-qt5
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%if 0%{?suse_version} >= 1550
%define build_qt6 1
%else
%define build_qt6 0
%endif

Name:           fcitx-qt5
Version:        1.2.7
Release:        1.52
Summary:        Fcitx QT5 Input Context
License:        BSD-3-Clause AND GPL-2.0-or-later AND GPL-3.0-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/fcitx/fcitx-qt5
Source:         %{URL}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.xz
Source99:       baselibs.conf
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  fcitx-devel >= 4.2.9.1
BuildRequires:  gcc-c++
BuildRequires:  libicu-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qtbase-private-headers-devel
BuildRequires:  libqt5-qtx11extras-devel
BuildRequires:  libxkbcommon-devel
%if %build_qt6
BuildRequires:  qt6-base-devel
BuildRequires:  qt6-base-private-devel
%endif
# fcitx-qt5 is using private QPA API, which can, and does break BC even in point releases,
# so we need to hardcode libQt5Gui5 version
%requires_eq    libQt5Gui5
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A QT5 input context plugin of Fcitx IM Framework.

%if %build_qt6
%package -n fcitx-qt6
Summary:        Qt6 IM module for Fcitx
Group:          System/I18n/Chinese
Supplements:    (fcitx and libQt6Core6)

%description -n fcitx-qt6
Qt6 IM module for Fcitx.
%endif

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Development header files for Fcitx input method framework (Qt5).

%prep
%setup

%build
%if %build_qt6
%cmake -DENABLE_QT6=ON
%else
%cmake
%endif
%make_build

%install
%cmake_install

%find_lang fcitx-qt5

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%if %build_qt6
%post -n fcitx-qt6 -p /sbin/ldconfig
%postun -n fcitx-qt6 -p /sbin/ldconfig

%files -n fcitx-qt6
%{_libdir}/qt6/plugins/platforminputcontexts/libfcitxplatforminputcontextplugin-qt6.so
%endif

%files -f fcitx-qt5.lang
%license COPYING
%dir %{_libdir}/fcitx/qt
%{_libdir}/fcitx/libexec/fcitx-qt5-gui-wrapper
%{_libdir}/libFcitxQt5*Addons.so.1
%{_libdir}/libFcitxQt5*Addons.so.1.0
%{_libdir}/fcitx/qt/libfcitx-quickphrase-editor5.so
%dir %{_libdir}/qt5/plugins/
%dir %{_libdir}/qt5/plugins/platforminputcontexts/
%{_libdir}/qt5/plugins/platforminputcontexts/libfcitxplatforminputcontextplugin.so

%files devel
%{_includedir}/FcitxQt5
%{_libdir}/libFcitxQt5*Addons.so
%{_libdir}/cmake/FcitxQt5*Addons/

%changelog
* Tue Jan 25 2022 Marguerite Su <i@marguerite.su>
- update to version 1.2.7
  * support Qt6
- drop fix-compilation-with-qt-5.11.patch, upstreamed
* Wed May 12 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.2.6
  * Updated translations
  * Fix potential recursion in libreoffice
  * Fix delete surrounding text
  * Allow building with QT_NO_KEYWORDS
* Tue Dec  1 2020 Marguerite Su <i@marguerite.su>
- update version 1.2.5
  * many fixes are ported from fcitx5 counter part during
    the developement. Some fixes related to focus and relative
    rect to allow the correct input window positioning on
    gnome-shell wayland mode.
- drop fix-remove-paths-warnings.patch, upstreamed
* Sat Sep 21 2019 Yunhe Guo <i@guoyunhe.me>
- Add upstream patch fix-remove-paths-warnings.patch
- Change COPYING from %%doc to %%license
* Sat Apr 28 2018 lbeltrame@kde.org
- Add upstream patch fix-compilation-with-qt-5.11.patch:
  * Fix compilation with Qt 5.11 (missing include)
* Sat Feb 10 2018 opensuse@trummer.xyz
- update version 1.2.2
  * We already changed reset of code to use "isRelease" for
    filterEventFallback. This check should be changed accordingly.
* Sat Dec  2 2017 i@marguerite.su
- update version 1.2.1
  * fix issue #27 and #28
  * Add relative rect support
- changes in version 1.2.0
  * Relicense platforminputcontext/ to BSD
  * do the real unwatch
  * prefer to recheck the availability after original service gone
  * set display type for fcitx5
  * add fcitx 5 format support
  * Adapt changes in fcitx5-qt to fix commitPreedit.
  * implement compatibility layer for fcitx5
  * try to reimplement im module with lgpl free code
  * make sure that quickphrae editor does not compile with qt4 header
  * move quickphrase editor to fcitx-qt5
- changes in version 1.1.1
  * fix high dpi screen position, only happen when you have two
    high dpi screen
  * use new cmake for package config
  * enforce cmake 3.1
  * handle the missing password flag
  * QInputMethod::update shouldn't be used by input method,
    just do query
  * workaround some qquickwidget bug
* Sat Feb 11 2017 i@marguerite.su
- update version 1.1.0
  * added guiwrapper for fcitx-qt5
  * fix build and add support for webengine
* Sat Dec  3 2016 i@marguerite.su
- update version 1.0.6
  * [qt5]fix inconsistency between qstring and ucs4 string
    when handle surrounding
  * [qt5]fromUcs4 expect a null terminated string by default,
    give it a size
  * [qt5]use new connection syntax
  * [qt5]use more nullptr
  * [qt5]remove usage of QPointer in icdata
  * [qt5]don't crash if window->screen() is null
* Wed Dec 23 2015 i@marguerite.su
- update version 1.0.5
  * implement locale in platform context
  * use link_directories for widgetaddons
  * use the correct var name
  * use some c++11 featues and fix ic not get recreated when
    fcitx restarts
  * clean proxy even it's invalid
* Mon Aug 31 2015 i@marguerite.su
- update version 1.0.4
  * fix the coordinates for high dpi in qt5
* Thu Jul  9 2015 i@marguerite.su
- update version 1.0.3
  * fix build w/ qt 5.5
* Sat May 30 2015 i@marguerite.su
- update version 1.0.2
  * fix google code issue 748
  * fix dependency check
  * fix leak
  * use xkbcommon for compose
  * install to lib instead of data
* Thu Apr  2 2015 i@marguerite.su
- update version 1.0.1
  * small fix against 1.0.0
- changes from 0.1.3 to 1.0.0
  * add COPYING
  * use platform name to check x11
  * access window function when context destructs is a bad thing
  * reorganize fcitx-qt5 library
- changes from 0.1.2 to 0.1.3
  * remove debug message
  * fix fcitx-qt5 display number resolution
  * fix pkg-config file
  * use filterEvent instead of x11FilterEvent
  * update dbus support
  * use new qt5 library name
* Fri Dec 12 2014 hrvoje.senjan@gmail.com
- fcitx-qt5 is using private QPA API, which can, and does break BC
  even in point releases, so we need to hardcode libQt5Gui5 version
* Mon Sep 15 2014 i@marguerite.su
- add baselibs.conf to Source
* Thu Sep 11 2014 hrvoje.senjan@gmail.com
- Fix baselibs requires, and shlib find-requires works
  also with baselibs
* Mon Jun  9 2014 i@marguerite.su
- update version 0.1.2
  * Fix github issue fcitx/fcitx-qt5#2
* Sun Mar  3 2013 i@marguerite.su
- update version 0.1.1
  * fix build and add libfcitx-qt5 for dbus.
- fix Qt5 dependency name from KDE:Qt50 repository.
- add baselibs.conf
  * because there're 32bit applications that needs input method
  * so we have to provide a 32bit input module too
* Tue Apr 17 2012 i@marguerite.su
- initial version 0.1.0
